@@ -163,7 +163,7 @@ public:
      *
      * \return finalized translation
      */
-    QString toString() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QString toString() const;
 
     /**
      * Like \c toString, but look for translation only in given languages.
@@ -175,7 +175,7 @@ public:
      * \param languages list of language codes (by decreasing priority)
      * \return finalized translation
      */
-    QString toString(const QStringList &languages) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QString toString(const QStringList &languages) const;
 
 #if 0 // until locale system is ready
     /**
@@ -198,7 +198,7 @@ public:
      * \param domain the translation domain
      * \return finalized translation
      */
-    QString toString(const char *domain) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QString toString(const char *domain) const;
 
     /**
      * Like \c toString, but resolve KUIT markup into given visual format.
@@ -211,7 +211,7 @@ public:
      * \param format the target visual format
      * \return finalized translation
      */
-    QString toString(Kuit::VisualFormat format) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QString toString(Kuit::VisualFormat format) const;
 
     /**
      * Indicate to look for translation only in given languages.
@@ -219,7 +219,7 @@ public:
      * \param languages list of language codes (by decreasing priority)
      * \return updated \c KLocalizedString
      */
-    KLocalizedString withLanguages(const QStringList &languages) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString withLanguages(const QStringList &languages) const;
 
 #if 0 // until locale system is ready
     /**
@@ -237,7 +237,7 @@ public:
      * \param domain the translation domain
      * \return updated \c KLocalizedString
      */
-    KLocalizedString withDomain(const char *domain) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString withDomain(const char *domain) const;
 
     /**
      * Indicate to resolve KUIT markup into given visual format.
@@ -247,7 +247,7 @@ public:
      * \param format the target visual format
      * \return updated \c KLocalizedString
      */
-    KLocalizedString withFormat(Kuit::VisualFormat format) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString withFormat(Kuit::VisualFormat format) const;
 
     /**
      * Substitute an int argument into the message.
@@ -261,8 +261,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(int a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(int a, int fieldWidth = 0, int base = 10,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute an unsigned int argument into the message.
@@ -276,8 +276,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(uint a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(uint a, int fieldWidth = 0, int base = 10,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute a long argument into the message.
@@ -291,8 +291,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(long a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(long a, int fieldWidth = 0, int base = 10,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute an unsigned long argument into the message.
@@ -306,8 +306,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(ulong a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(ulong a, int fieldWidth = 0, int base = 10,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute a long long argument into the message.
@@ -321,8 +321,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(qlonglong a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(qlonglong a, int fieldWidth = 0, int base = 10,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute an unsigned long long argument into the message.
@@ -336,8 +336,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(qulonglong a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(qulonglong a, int fieldWidth = 0, int base = 10,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute a double argument into the message.
@@ -351,9 +351,9 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(double a, int fieldWidth = 0,
-                          char format = 'g', int precision = -1,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(double a, int fieldWidth = 0,
+                                            char format = 'g', int precision = -1,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute a \c QChar argument into the message.
@@ -365,8 +365,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(QChar a, int fieldWidth = 0,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(QChar a, int fieldWidth = 0,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute a \c QString argument into the message.
@@ -378,8 +378,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(const QString &a, int fieldWidth = 0,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(const QString &a, int fieldWidth = 0,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Substitute another \c KLocalizedString into the message.
@@ -391,8 +391,8 @@ public:
      *                 field width is greater than argument width
      * \return updated \c KLocalizedString
      */
-    KLocalizedString subs(const KLocalizedString &a, int fieldWidth = 0,
-                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString subs(const KLocalizedString &a, int fieldWidth = 0,
+                                            QChar fillChar = QLatin1Char(' ')) const;
 
     /**
      * Add dynamic context to the message.
@@ -403,8 +403,8 @@ public:
      * \param value context value
      * \return updated \c KLocalizedString
      */
-    KLocalizedString inContext(const QString &key,
-                               const QString &value) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString inContext(const QString &key,
+                                                 const QString &value) const;
 
     /**
      * Relax matching between placeholders and arguments.
@@ -423,7 +423,7 @@ public:
      *
      * \return updated \c KLocalizedString
      */
-    KLocalizedString relaxSubs() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString relaxSubs() const;
 
     /**
      * Do not resolve KUIT markup.
@@ -435,7 +435,7 @@ public:
      *
      * \return updated \c KLocalizedString
      */
-    KLocalizedString ignoreMarkup() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KLocalizedString ignoreMarkup() const;
 
     /**
      * Set the given domain as application's main domain.
@@ -557,6 +557,16 @@ public:
      */
     static QSet<QString> availableDomainTranslations(const QByteArray &domain);
 
+    /*
+     * Load locales for a domain from a specific location
+     * This is useful for resources which have their translation files
+     * outside of the usual $XDG_DATA_DIRS/locales location
+     *
+     * \param the domain to load resources from
+     * \path the full file path to the locale directory
+     */
+    static void addDomainLocaleDir(const QByteArray &domain, const QString &path);
+
     /**
      * Find a path to the localized file for the given original path.
      *
@@ -572,7 +582,7 @@ public:
      *
      * \return path to the localized file if found, original path otherwise
      */
-    static QString localizedFilePath(const QString &filePath) Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT static QString localizedFilePath(const QString &filePath);
 
     /**
      * Remove accelerator marker from a UI text label.
@@ -588,7 +598,7 @@ public:
      * \param label UI label which may contain an accelerator marker
      * \return label without the accelerator marker
      */
-    static QString removeAcceleratorMarker(const QString &label) Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT static QString removeAcceleratorMarker(const QString &label);
 
     /**
      * Translate a message with Qt semantics.
@@ -605,8 +615,8 @@ public:
      *             with roundtrip TS->PO->TS through
      *             Qt's \c lupdate and \c lconvert commands.
      */
-    KI18N_DEPRECATED static QString translateQt(const char *context, const char *text,
-                               const char *comment, int n) Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT KI18N_DEPRECATED static QString translateQt(const char *context, const char *text,
+                               const char *comment, int n);
 
     /**
      * Add another domain to search for Qt translations.
@@ -649,7 +659,7 @@ private:
 // Do not document every multi-argument i18n* call separately,
 // but provide special quasi-calls that only Doxygen sees.
 // Placed in front of ki18n* calls, because i18n* are more basic.
-#ifdef DOXYGEN_PREPROC
+#ifdef DOXYGEN_SHOULD_SKIP_THIS
 
 /**
  * Translate a string and substitute any arguments.
@@ -850,7 +860,7 @@ QString xi18ndcp(const char *domain,
                  const char *context, const char *singular, const char *plural,
                  const TYPE &arg...);
 
-#endif // DOXYGEN_PREPROC
+#endif // DOXYGEN_SHOULD_SKIP_THIS
 
 /**
  * Create non-finalized translated string.
@@ -1090,7 +1100,7 @@ inline QString tr2xi18nd(const char *domain,
     }
 }
 
-#ifndef DOXYGEN_PREPROC
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 
 #ifndef NDEBUG
 #define I18N_ERR_MSG String_literal_as_second_argument_to_i18n___Perhaps_you_need_i18nc_or_i18np
@@ -1956,11 +1966,11 @@ inline QString xi18ndcp(const char *domain, const char *context, const char *sin
 }
 // <<<<< End of markup-aware context-plural calls with domain
 
-#endif // DOXYGEN_PREPROC
+#endif // DOXYGEN_SHOULD_SKIP_THIS
 
 #endif // KLOCALIZEDSTRING_H
 
-#ifndef DOXYGEN_PREPROC
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 
 // Outside of include guards, to be able to map and unmap domains
 // by successive inclusions of this header
@@ -2005,4 +2015,4 @@ inline QString xi18ndcp(const char *domain, const char *context, const char *sin
 #undef tr2xi18n
 #endif
 
-#endif // DOXYGEN_PREPROC
+#endif // DOXYGEN_SHOULD_SKIP_THIS
